==> haskell-haddock-library-1.5.0.1-7-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-haddock-library.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: z-haddock-library-z-attoparsec
version: 1.5.0.1
package-name: haddock-library
lib-name: attoparsec
id: haddock-library-1.5.0.1-3bSoLVlVajaJnQtUTgKTDD-attoparsec
key: haddock-library-1.5.0.1-3bSoLVlVajaJnQtUTgKTDD-attoparsec
license: BSD-3-Clause
maintainer: Alex Biehl <alexbiehl@gmail.com>, Simon Hengel <sol@typeful.net>, Mateusz Kowalczyk <fuuzetsu@fuuzetsu.co.uk>
homepage: http://www.haskell.org/haddock/
synopsis: Library exposing some functionality of Haddock.
description:
    Haddock is a documentation-generation tool for Haskell
    libraries. These modules expose some functionality of it
    without pulling in the GHC dependency. Please note that the
    API is likely to change so specify upper bounds in your
    project if you can'\''t release often. For interacting with Haddock
    itself, see the ‘haddock’ package.
category: Documentation
abi: 78938a5bb9c8a480f6551d13dcf09acf
exposed-modules:
    Data.Attoparsec.ByteString Data.Attoparsec.ByteString.Char8
    Data.Attoparsec.Combinator
hidden-modules: Data.Attoparsec Data.Attoparsec.ByteString.Buffer
                Data.Attoparsec.ByteString.FastSet
                Data.Attoparsec.ByteString.Internal Data.Attoparsec.Internal
                Data.Attoparsec.Internal.Fhthagn Data.Attoparsec.Internal.Types
                Data.Attoparsec.Number
import-dirs: /usr/lib/ghc-8.4.3/site-local/haddock-library-1.5.0.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/haddock-library-1.5.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/haddock-library-1.5.0.1
hs-libraries: HShaddock-library-1.5.0.1-3bSoLVlVajaJnQtUTgKTDD-attoparsec
depends:
    base-4.11.1.0 bytestring-0.10.8.2 deepseq-1.4.3.0
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             bytestring-0.10.8.2=76943c00398d547fb172e56c2f93c635
             deepseq-1.4.3.0=00d8faa7363cb0be9acd709ef6549e22
haddock-interfaces: /usr/share/doc/haskell-haddock-library/html/haddock-library.haddock
haddock-html: /usr/share/doc/haskell-haddock-library/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: haddock-library
version: 1.5.0.1
id: haddock-library-1.5.0.1-ChfkpmEoTPbLRs9WD9MJOM
key: haddock-library-1.5.0.1-ChfkpmEoTPbLRs9WD9MJOM
license: BSD-3-Clause
maintainer: Alex Biehl <alexbiehl@gmail.com>, Simon Hengel <sol@typeful.net>, Mateusz Kowalczyk <fuuzetsu@fuuzetsu.co.uk>
homepage: http://www.haskell.org/haddock/
synopsis: Library exposing some functionality of Haddock.
description:
    Haddock is a documentation-generation tool for Haskell
    libraries. These modules expose some functionality of it
    without pulling in the GHC dependency. Please note that the
    API is likely to change so specify upper bounds in your
    project if you can'\''t release often. For interacting with Haddock
    itself, see the ‘haddock’ package.
category: Documentation
abi: b9f1a0dc7ebe77587ed1c0e9778de8b1
exposed: True
exposed-modules:
    Documentation.Haddock.Doc Documentation.Haddock.Markup
    Documentation.Haddock.Parser Documentation.Haddock.Parser.Monad
    Documentation.Haddock.Types Documentation.Haddock.Utf8
hidden-modules: Documentation.Haddock.Parser.Util
import-dirs: /usr/lib/ghc-8.4.3/site-local/haddock-library-1.5.0.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/haddock-library-1.5.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/haddock-library-1.5.0.1
hs-libraries: HShaddock-library-1.5.0.1-ChfkpmEoTPbLRs9WD9MJOM
depends:
    base-4.11.1.0 bytestring-0.10.8.2 containers-0.5.11.0
    transformers-0.5.5.0
    haddock-library-1.5.0.1-3bSoLVlVajaJnQtUTgKTDD-attoparsec
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             bytestring-0.10.8.2=76943c00398d547fb172e56c2f93c635
             containers-0.5.11.0=7795138514357bd2e41eaf59b6cfce4f
             transformers-0.5.5.0=633c3e5ec737c360775b452ce9aa1e0b
             haddock-library-1.5.0.1-3bSoLVlVajaJnQtUTgKTDD-attoparsec=78938a5bb9c8a480f6551d13dcf09acf
haddock-interfaces: /usr/share/doc/haskell-haddock-library/html/haddock-library.haddock
haddock-html: /usr/share/doc/haskell-haddock-library/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-haddock-library-1.5.0.1-11-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-haddock-library.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: z-haddock-library-z-attoparsec
version: 1.5.0.1
package-name: haddock-library
lib-name: attoparsec
id: haddock-library-1.5.0.1-IMXedUuaawt8Tdym9sLAbT-attoparsec
key: haddock-library-1.5.0.1-IMXedUuaawt8Tdym9sLAbT-attoparsec
license: BSD-3-Clause
maintainer: Alex Biehl <alexbiehl@gmail.com>, Simon Hengel <sol@typeful.net>, Mateusz Kowalczyk <fuuzetsu@fuuzetsu.co.uk>
homepage: http://www.haskell.org/haddock/
synopsis: Library exposing some functionality of Haddock.
description:
    Haddock is a documentation-generation tool for Haskell
    libraries. These modules expose some functionality of it
    without pulling in the GHC dependency. Please note that the
    API is likely to change so specify upper bounds in your
    project if you can'\''t release often. For interacting with Haddock
    itself, see the ‘haddock’ package.
category: Documentation
abi: e91ae67cbd0ae734868d94dc0a56fa20
exposed-modules:
    Data.Attoparsec.ByteString Data.Attoparsec.ByteString.Char8
    Data.Attoparsec.Combinator
hidden-modules: Data.Attoparsec Data.Attoparsec.ByteString.Buffer
                Data.Attoparsec.ByteString.FastSet
                Data.Attoparsec.ByteString.Internal Data.Attoparsec.Internal
                Data.Attoparsec.Internal.Fhthagn Data.Attoparsec.Internal.Types
                Data.Attoparsec.Number
import-dirs: /usr/lib/ghc-8.4.3/site-local/haddock-library-1.5.0.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/haddock-library-1.5.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/haddock-library-1.5.0.1
hs-libraries: HShaddock-library-1.5.0.1-IMXedUuaawt8Tdym9sLAbT-attoparsec
depends:
    base-4.11.1.0 bytestring-0.10.8.2 deepseq-1.4.3.0
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             bytestring-0.10.8.2=76943c00398d547fb172e56c2f93c635
             deepseq-1.4.3.0=00d8faa7363cb0be9acd709ef6549e22
haddock-interfaces: /usr/share/doc/haskell-haddock-library/html/haddock-library.haddock
haddock-html: /usr/share/doc/haskell-haddock-library/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: haddock-library
version: 1.5.0.1
id: haddock-library-1.5.0.1-EmkMgjLSd7kJP7iDHIXydH
key: haddock-library-1.5.0.1-EmkMgjLSd7kJP7iDHIXydH
license: BSD-3-Clause
maintainer: Alex Biehl <alexbiehl@gmail.com>, Simon Hengel <sol@typeful.net>, Mateusz Kowalczyk <fuuzetsu@fuuzetsu.co.uk>
homepage: http://www.haskell.org/haddock/
synopsis: Library exposing some functionality of Haddock.
description:
    Haddock is a documentation-generation tool for Haskell
    libraries. These modules expose some functionality of it
    without pulling in the GHC dependency. Please note that the
    API is likely to change so specify upper bounds in your
    project if you can'\''t release often. For interacting with Haddock
    itself, see the ‘haddock’ package.
category: Documentation
abi: 35f88608a77b7adbf3b91f8b090696cb
exposed: True
exposed-modules:
    Documentation.Haddock.Doc Documentation.Haddock.Markup
    Documentation.Haddock.Parser Documentation.Haddock.Parser.Monad
    Documentation.Haddock.Types Documentation.Haddock.Utf8
hidden-modules: Documentation.Haddock.Parser.Util
import-dirs: /usr/lib/ghc-8.4.3/site-local/haddock-library-1.5.0.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/haddock-library-1.5.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/haddock-library-1.5.0.1
hs-libraries: HShaddock-library-1.5.0.1-EmkMgjLSd7kJP7iDHIXydH
depends:
    base-4.11.1.0 bytestring-0.10.8.2 containers-0.5.11.0
    transformers-0.5.5.0
    haddock-library-1.5.0.1-IMXedUuaawt8Tdym9sLAbT-attoparsec
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             bytestring-0.10.8.2=76943c00398d547fb172e56c2f93c635
             containers-0.5.11.0=7795138514357bd2e41eaf59b6cfce4f
             transformers-0.5.5.0=633c3e5ec737c360775b452ce9aa1e0b
             haddock-library-1.5.0.1-IMXedUuaawt8Tdym9sLAbT-attoparsec=e91ae67cbd0ae734868d94dc0a56fa20
haddock-interfaces: /usr/share/doc/haskell-haddock-library/html/haddock-library.haddock
haddock-html: /usr/share/doc/haskell-haddock-library/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
